<?php

namespace Drupal\campaign_kit\Plugin\Block\DonateComponent;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormBuilderInterface;

/**
 * Provides a 'DonateComponent' block.
 *
 * @Block(
 *  id = "donate_component",
 *  admin_label = @Translation("Donate Component"),
 * )
 */
class DonateComponent extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\Core\Form\FormBuilderInterface definition.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a new Donate Component object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The Form Builder Interface.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $form_builder) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $configurationBlock = $configuration;
    $pluginId = $plugin_id;
    $pluginDefinition = $plugin_definition;
    $formBuilder = $container->get('form_builder');

    return new static(
      $configurationBlock,
      $pluginId,
      $pluginDefinition,
      $formBuilder
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['include_teams'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Include teams?'),
      '#default_value' => $this->configuration['include_teams']?: TRUE,
      '#weight' => '5',
      '#required' => TRUE,
    ];

    $form['thank_you_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Thank you URL"),
      '#default_value' => $this->configuration['thank_you_url'],
      '#maxlength' => '60',
      '#description' => $this->t('Example: /home, https://www.drupal.org/'),
      '#attributes' => ['placeholder' => $this->t('Thank you URL')],
      '#weight' => '6',
      '#required' => TRUE,
    ];

    $form['donate_failed_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t("Donate Failed URL"),
      '#default_value' => $this->configuration['donate_failed_url'],
      '#maxlength' => '60',
      '#description' => $this->t('Example: /home, https://www.drupal.org/'),
      '#attributes' => ['placeholder' => $this->t('Donate Failed URL')],
      '#weight' => '7',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['include_teams'] = $form_state->getValue('include_teams');
    $this->configuration['thank_you_url'] = $form_state->getValue('thank_you_url');
    $this->configuration['donate_failed_url'] = $form_state->getValue('donate_failed_url');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    // Add template.
    $build['#theme'] = 'DonateComponent';
    // Attach library.
    $build['#attached']['library'] = ['campaign_kit/donate-component-styling'];

    $build['#include_teams']['#markup'] = '<p>' . $this->configuration['include_teams'] . '</p>';

    // Get Donate form and pass parameters.
    $form = $this->formBuilder->getForm('Drupal\campaign_kit\Form\DonateForm', $this->configuration['thank_you_url'], $this->configuration['donate_failed_url']);
    if ($form) {
      $build['#donate_form'] = $form;
    }

    return $build;
  }

}
